@@ -1411,7 +1411,7 @@ gint main(gint argc, gchar *argv[])
     GtkWidget *power_button, *alarm_button, *play_button, *pause_button,
               *stop_button, *next_button, *previous_button,
               *search_button, *add_button, *shuffle_button,
-              *repeat_button, *brightness_button, *snooze_button;
+              *repeat_button, *brightness_button, *snooze_button, *vol_up_button, *vol_down_button;
 
     my_printf("%s()\n", __PRETTY_FUNCTION__);
 
@@ -1508,66 +1508,91 @@ gint main(gint argc, gchar *argv[])
     g_signal_connect(G_OBJECT(snooze_button), "clicked",
                           G_CALLBACK(main_screen_button_cb),
                           "IrDispatchCommand CK_SNOOZE\n");
+    
     alarm_button = gtk_button_new_with_label(_("Alarm"));
     gtk_container_add(GTK_CONTAINER(hbox1), alarm_button);
     g_signal_connect(G_OBJECT(alarm_button), "clicked",
                           G_CALLBACK(main_screen_button_cb),
                           "IrDispatchCommand CK_ALARM\n");
+    
     play_button = gtk_button_new_with_label(_("Play"));
     gtk_container_add(GTK_CONTAINER(hbox1), play_button);
     g_signal_connect(G_OBJECT(play_button), "clicked",
                           G_CALLBACK(main_screen_button_cb),
                           "IrDispatchCommand CK_PLAY\n");
+    
     pause_button = gtk_button_new_with_label(_("Pause"));
     gtk_container_add(GTK_CONTAINER(hbox1), pause_button);
     g_signal_connect(G_OBJECT(pause_button), "clicked",
                           G_CALLBACK(main_screen_button_cb),
                           "IrDispatchCommand CK_PAUSE\n");
+    
     stop_button = gtk_button_new_with_label(_("Stop"));
     gtk_container_add(GTK_CONTAINER(hbox1), stop_button);
     g_signal_connect(G_OBJECT(stop_button), "clicked",
                           G_CALLBACK(main_screen_button_cb),
                           "IrDispatchCommand CK_STOP\n");
+    
     previous_button = gtk_button_new_with_label(_("Previous"));
     gtk_container_add(GTK_CONTAINER(hbox1), previous_button);
     g_signal_connect(G_OBJECT(previous_button), "clicked",
                           G_CALLBACK(main_screen_button_cb),
                           "IrDispatchCommand CK_PREVIOUS\n");
+    
     next_button = gtk_button_new_with_label(_("Next"));
     gtk_container_add(GTK_CONTAINER(hbox1), next_button);
     g_signal_connect(G_OBJECT(next_button), "clicked",
                           G_CALLBACK(main_screen_button_cb),
                           "IrDispatchCommand CK_NEXT\n");
+    /* Volume Up */
+    vol_up_button = gtk_button_new_with_label(_("Vol +"));
+    gtk_container_add(GTK_CONTAINER(hbox1), vol_up_button);
+    g_signal_connect(G_OBJECT(vol_up_button), "clicked",
+                          G_CALLBACK(main_screen_button_cb),
+                          "IrDispatchCommand CK_VOLUME_UP\n");
+    
     power_button = gtk_button_new_with_label(_("Power"));
     gtk_container_add(GTK_CONTAINER(hbox2), power_button);
     g_signal_connect(G_OBJECT(power_button), "clicked",
                           G_CALLBACK(main_screen_button_cb),
                           "IrDispatchCommand CK_POWER\n");
+    
     search_button = gtk_button_new_with_label(_("Search"));
     gtk_container_add(GTK_CONTAINER(hbox2), search_button);
     g_signal_connect(G_OBJECT(search_button), "clicked",
                           G_CALLBACK(main_screen_button_cb),
                           "IrDispatchCommand CK_SEARCH\n");
+    
     add_button = gtk_button_new_with_label(_("Add"));
     gtk_container_add(GTK_CONTAINER(hbox2), add_button);
     g_signal_connect(G_OBJECT(add_button), "clicked",
                           G_CALLBACK(main_screen_button_cb),
                           "IrDispatchCommand CK_ADD\n");
+    
     shuffle_button = gtk_button_new_with_label(_("Shuffle"));
     gtk_container_add(GTK_CONTAINER(hbox2), shuffle_button);
     g_signal_connect(G_OBJECT(shuffle_button), "clicked",
                           G_CALLBACK(main_screen_button_cb),
                           "IrDispatchCommand CK_SHUFFLE\n");
+    
     repeat_button = gtk_button_new_with_label(_("Repeat"));
     gtk_container_add(GTK_CONTAINER(hbox2), repeat_button);
     g_signal_connect(G_OBJECT(repeat_button), "clicked",
                           G_CALLBACK(main_screen_button_cb),
                           "IrDispatchCommand CK_REPEAT\n");
+    
     brightness_button = gtk_button_new_with_label(_("Brightness"));
     gtk_container_add(GTK_CONTAINER(hbox2), brightness_button);
     g_signal_connect(G_OBJECT(brightness_button), "clicked",
                           G_CALLBACK(main_screen_button_cb),
                           "IrDispatchCommand CK_BRIGHTNESS\n");
+    /* Volume Down */
+    vol_down_button = gtk_button_new_with_label(_("Vol -"));
+    gtk_container_add(GTK_CONTAINER(hbox2), vol_down_button);
+    g_signal_connect(G_OBJECT(vol_down_button), "clicked",
+                          G_CALLBACK(main_screen_button_cb),
+                          "IrDispatchCommand CK_VOLUME_DOWN\n");
+
 
     menu_init();
 
